==> apache-camel-3.4.0-src.zip: apache-camel-3.4.0/core/camel-core/src/test/java/org/apache/camel/processor/ChoiceWhenNotPredicateTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.apache.camel.builder.PredicateBuilder.not;

public class ChoiceWhenNotPredicateTest extends ContextTestSupport {

    @Test
    public void testPeople() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:people");
        mock.expectedMessageCount(1);

        template.sendBodyAndHeader("direct:start", "Hello World", "username", "donald");

        assertMockEndpointsSatisfied();
    }

    @Test
    public void testAnimals() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:animals");
        mock.expectedMessageCount(1);

        template.sendBodyAndHeader("direct:start", "Hello World", "username", "pluto");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // START SNIPPET: e1
                from("direct:start").choice().when(not(header("username").regex("goofy|pluto"))).to("mock:people").otherwise().to("mock:animals").end();
                // END SNIPPET: e1
            }
        };
    }

}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/core/camel-core/src/test/java/org/apache/camel/processor/ChoiceWhenNotPredicateTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.apache.camel.builder.PredicateBuilder.not;

public class ChoiceWhenNotPredicateTest extends ContextTestSupport {

    @Test
    public void testPeople() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:people");
        mock.expectedMessageCount(1);

        template.sendBodyAndHeader("direct:start", "Hello World", "username", "donald");

        assertMockEndpointsSatisfied();
    }

    @Test
    public void testAnimals() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:animals");
        mock.expectedMessageCount(1);

        template.sendBodyAndHeader("direct:start", "Hello World", "username", "pluto");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // START SNIPPET: e1
                from("direct:start").choice().when(not(header("username").regex("goofy|pluto"))).to("mock:people").otherwise()
                        .to("mock:animals").end();
                // END SNIPPET: e1
            }
        };
    }

}
